
# DYNAMO PROJECT - FED4FIRE+ 
## PROJECT SUMMARY

The main objective of the DYNAMO Fed4FIRE+ experiment was to perform Network
Function Virtualization (NFV) Management and Network Orchestration (MANO) of a
cellular network on top of cloud infrastructures, exploring one of the key
enabling technologies for 5G systems and beyond.  DYNAMO used cloud and radio
access facilities at the IRIS testbed and cloud facilities at the University of
Vigo (UVIGO) to deploy an end-to-end (E2E) cellular network and perform elastic
changes on it if needed. The geographic distance in between facilitated the
setup of a realistic Multi-Access Edge Computing (MEC) use case, where the
virtual Evolved Packet Core (vEPC) was deployed at UVIGO (Spain) and the access
network, i.e., the User Equipment (UE), the e-Node-B (eNB) and edge cloud, were
implemented on IRIS testbed (Ireland).  

While the initial deployment of the E2E cellular network may be considered as
static, DYNAMO showcases the elasticity that an E2E cellular network may need in
runtime. Hence, we presented a use case consisting of a latency sensitive E2E
cellular network (network slice), where the endpoint of the UE connection was
initially located in the core (UVIGO) but then migrated to the edge (IRIS), in
case the UE's latency ranges were unacceptable. 

In this regard, the UE reported the experienced latency to Open Network
Automation Platform (ONAP), which is responsible to trigger specific
policy-driven control actions if a predefined Service-Level Agreement (SLA) is
violated. **This datased includes the reports provided by the UE to ONAP.**

As a result, the endpoint of the data plane of the UE is automatically
moved to the access network (IRIS) thus reducing significantly the latency for
the UE.  For the access part of the network, we implemented one srsLTE e-Node-B
(eNB), one srsLTE User Equipment (UE) and a Devstack (Edge Cloud) in virtual
machines on IRIS testbed. In addition, we also implemented an SDN switch
controlled by an ONOS SDN controller. For the core part of the network, we
considered a disaggregated vEPC from Open Air Interface (OAI) on a Devstack (Core
Cloud) at UVIGO. 

DYNAMO has succeeded in the integration of a broad set of network elements and
technologies between the two different domains (UVIGO and IRIS testbed) and
fulfilled all initial objectives: (i) establishing communication between ONAP
and IRIS testbed to deploy generic VNFs on core and edge clouds, (ii),
deployment of an E2E cellular network with UE and eNB in IRIS and the vEPC at
UVIGO, (iii), sending telemetry of the UE to ONAP and (iv) designing and testing
closed-loop control actions in ONAP to migrate the data plane of the UE to the
edge in case of unsatisfactorily SLA.  DYNAMO paves the way to a broad set of
future 5G experiments that will require resource orchestration, such as the
deployment of network slices or the automatic scheduling of services in the
limited resources of Edge Clouds.

## DATA CONTAINED IN THIS FILE 

This repository contains the information sent from the UE to ONAP, in order to
decide if the latency between the UE and the PGW is OK or if an action has to be
considered to reduce such latency. 

There are two sets of experiments: 
* Experiments completed with a low load in the network (LIGHTLOAD status).
* Experiments completed with a high communication load (HEAVYLOAD status).


## DIRECTORY TREE
This repository is organized in two folders:
* LIGHTLOAD: The UE is performing just a ping operation and
  reporting the RTT value to ONAP DCAE VES Collector service. 
* HEAVYLOAD: The UE is performing a periodic ping while a large file is being
  downloaded at the same time.
 

## NAMING CONVENTION

The data obtained in each experiment is included as an independent file. Files
are named as R?-LIGHTLOAD or R?-HEAVYLOAD,  where "?" represents the number of
the experiment and LIGHTLOAD or HEAVYLOAD indicates whether the communication
link was being stressed or not. 

## CONTENTS OF EACH FILE

Files contain plain text lines with three types of messages: 

* "The ping to 10.32.0.1 is: 89.7ms. Metric sent to ONAP"
	* The measured latency between the UE and the PGW.
* "Reached the threshold limit."  
	* The measured latency between the UE and the PGW reached the threshold
	  limit (130ms). ONAP will start different actions to instantiate a new
	  PGW on the network edge.  
* "PGW changed to edge" 
	* The new SPGW was deployed at the edge, and now the traffic received
	  from the UE uses this instance.


## NOTES

* Latency is measured every second.
* The time to instantiate the SPGW at the edge is not constant.
* The experiment finishes after the UE traffic starts using the edge SPGW.



